# coding: utf-8

"""
    Component Database API

    The API that provides access to Component Database data.  # noqa: E501

    The version of the OpenAPI document: 3.15.4
    Contact: djarosz@anl.gov
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from cdbApi.configuration import Configuration


class ItemDomainMachineDesignAllOf(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'membership_loaded': 'bool',
        'move_to_trash_error_msg': 'str',
        'move_to_trash_warning_msg': 'str',
        'alternate_name': 'str',
        'assigned_item': 'Item',
        'is_housed': 'bool',
        'assigned_represented_element': 'ItemElement',
        'status_property_type_name': 'str',
        'move_to_trash_row_style': 'str',
        'location_item': 'ItemDomainLocation'
    }

    attribute_map = {
        'membership_loaded': 'membershipLoaded',
        'move_to_trash_error_msg': 'moveToTrashErrorMsg',
        'move_to_trash_warning_msg': 'moveToTrashWarningMsg',
        'alternate_name': 'alternateName',
        'assigned_item': 'assignedItem',
        'is_housed': 'isHoused',
        'assigned_represented_element': 'assignedRepresentedElement',
        'status_property_type_name': 'statusPropertyTypeName',
        'move_to_trash_row_style': 'moveToTrashRowStyle',
        'location_item': 'locationItem'
    }

    def __init__(self, membership_loaded=None, move_to_trash_error_msg=None, move_to_trash_warning_msg=None, alternate_name=None, assigned_item=None, is_housed=None, assigned_represented_element=None, status_property_type_name=None, move_to_trash_row_style=None, location_item=None, local_vars_configuration=None):  # noqa: E501
        """ItemDomainMachineDesignAllOf - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._membership_loaded = None
        self._move_to_trash_error_msg = None
        self._move_to_trash_warning_msg = None
        self._alternate_name = None
        self._assigned_item = None
        self._is_housed = None
        self._assigned_represented_element = None
        self._status_property_type_name = None
        self._move_to_trash_row_style = None
        self._location_item = None
        self.discriminator = None

        if membership_loaded is not None:
            self.membership_loaded = membership_loaded
        if move_to_trash_error_msg is not None:
            self.move_to_trash_error_msg = move_to_trash_error_msg
        if move_to_trash_warning_msg is not None:
            self.move_to_trash_warning_msg = move_to_trash_warning_msg
        if alternate_name is not None:
            self.alternate_name = alternate_name
        if assigned_item is not None:
            self.assigned_item = assigned_item
        if is_housed is not None:
            self.is_housed = is_housed
        if assigned_represented_element is not None:
            self.assigned_represented_element = assigned_represented_element
        if status_property_type_name is not None:
            self.status_property_type_name = status_property_type_name
        if move_to_trash_row_style is not None:
            self.move_to_trash_row_style = move_to_trash_row_style
        if location_item is not None:
            self.location_item = location_item

    @property
    def membership_loaded(self):
        """Gets the membership_loaded of this ItemDomainMachineDesignAllOf.  # noqa: E501


        :return: The membership_loaded of this ItemDomainMachineDesignAllOf.  # noqa: E501
        :rtype: bool
        """
        return self._membership_loaded

    @membership_loaded.setter
    def membership_loaded(self, membership_loaded):
        """Sets the membership_loaded of this ItemDomainMachineDesignAllOf.


        :param membership_loaded: The membership_loaded of this ItemDomainMachineDesignAllOf.  # noqa: E501
        :type: bool
        """

        self._membership_loaded = membership_loaded

    @property
    def move_to_trash_error_msg(self):
        """Gets the move_to_trash_error_msg of this ItemDomainMachineDesignAllOf.  # noqa: E501


        :return: The move_to_trash_error_msg of this ItemDomainMachineDesignAllOf.  # noqa: E501
        :rtype: str
        """
        return self._move_to_trash_error_msg

    @move_to_trash_error_msg.setter
    def move_to_trash_error_msg(self, move_to_trash_error_msg):
        """Sets the move_to_trash_error_msg of this ItemDomainMachineDesignAllOf.


        :param move_to_trash_error_msg: The move_to_trash_error_msg of this ItemDomainMachineDesignAllOf.  # noqa: E501
        :type: str
        """

        self._move_to_trash_error_msg = move_to_trash_error_msg

    @property
    def move_to_trash_warning_msg(self):
        """Gets the move_to_trash_warning_msg of this ItemDomainMachineDesignAllOf.  # noqa: E501


        :return: The move_to_trash_warning_msg of this ItemDomainMachineDesignAllOf.  # noqa: E501
        :rtype: str
        """
        return self._move_to_trash_warning_msg

    @move_to_trash_warning_msg.setter
    def move_to_trash_warning_msg(self, move_to_trash_warning_msg):
        """Sets the move_to_trash_warning_msg of this ItemDomainMachineDesignAllOf.


        :param move_to_trash_warning_msg: The move_to_trash_warning_msg of this ItemDomainMachineDesignAllOf.  # noqa: E501
        :type: str
        """

        self._move_to_trash_warning_msg = move_to_trash_warning_msg

    @property
    def alternate_name(self):
        """Gets the alternate_name of this ItemDomainMachineDesignAllOf.  # noqa: E501


        :return: The alternate_name of this ItemDomainMachineDesignAllOf.  # noqa: E501
        :rtype: str
        """
        return self._alternate_name

    @alternate_name.setter
    def alternate_name(self, alternate_name):
        """Sets the alternate_name of this ItemDomainMachineDesignAllOf.


        :param alternate_name: The alternate_name of this ItemDomainMachineDesignAllOf.  # noqa: E501
        :type: str
        """

        self._alternate_name = alternate_name

    @property
    def assigned_item(self):
        """Gets the assigned_item of this ItemDomainMachineDesignAllOf.  # noqa: E501


        :return: The assigned_item of this ItemDomainMachineDesignAllOf.  # noqa: E501
        :rtype: Item
        """
        return self._assigned_item

    @assigned_item.setter
    def assigned_item(self, assigned_item):
        """Sets the assigned_item of this ItemDomainMachineDesignAllOf.


        :param assigned_item: The assigned_item of this ItemDomainMachineDesignAllOf.  # noqa: E501
        :type: Item
        """

        self._assigned_item = assigned_item

    @property
    def is_housed(self):
        """Gets the is_housed of this ItemDomainMachineDesignAllOf.  # noqa: E501


        :return: The is_housed of this ItemDomainMachineDesignAllOf.  # noqa: E501
        :rtype: bool
        """
        return self._is_housed

    @is_housed.setter
    def is_housed(self, is_housed):
        """Sets the is_housed of this ItemDomainMachineDesignAllOf.


        :param is_housed: The is_housed of this ItemDomainMachineDesignAllOf.  # noqa: E501
        :type: bool
        """

        self._is_housed = is_housed

    @property
    def assigned_represented_element(self):
        """Gets the assigned_represented_element of this ItemDomainMachineDesignAllOf.  # noqa: E501


        :return: The assigned_represented_element of this ItemDomainMachineDesignAllOf.  # noqa: E501
        :rtype: ItemElement
        """
        return self._assigned_represented_element

    @assigned_represented_element.setter
    def assigned_represented_element(self, assigned_represented_element):
        """Sets the assigned_represented_element of this ItemDomainMachineDesignAllOf.


        :param assigned_represented_element: The assigned_represented_element of this ItemDomainMachineDesignAllOf.  # noqa: E501
        :type: ItemElement
        """

        self._assigned_represented_element = assigned_represented_element

    @property
    def status_property_type_name(self):
        """Gets the status_property_type_name of this ItemDomainMachineDesignAllOf.  # noqa: E501


        :return: The status_property_type_name of this ItemDomainMachineDesignAllOf.  # noqa: E501
        :rtype: str
        """
        return self._status_property_type_name

    @status_property_type_name.setter
    def status_property_type_name(self, status_property_type_name):
        """Sets the status_property_type_name of this ItemDomainMachineDesignAllOf.


        :param status_property_type_name: The status_property_type_name of this ItemDomainMachineDesignAllOf.  # noqa: E501
        :type: str
        """

        self._status_property_type_name = status_property_type_name

    @property
    def move_to_trash_row_style(self):
        """Gets the move_to_trash_row_style of this ItemDomainMachineDesignAllOf.  # noqa: E501


        :return: The move_to_trash_row_style of this ItemDomainMachineDesignAllOf.  # noqa: E501
        :rtype: str
        """
        return self._move_to_trash_row_style

    @move_to_trash_row_style.setter
    def move_to_trash_row_style(self, move_to_trash_row_style):
        """Sets the move_to_trash_row_style of this ItemDomainMachineDesignAllOf.


        :param move_to_trash_row_style: The move_to_trash_row_style of this ItemDomainMachineDesignAllOf.  # noqa: E501
        :type: str
        """

        self._move_to_trash_row_style = move_to_trash_row_style

    @property
    def location_item(self):
        """Gets the location_item of this ItemDomainMachineDesignAllOf.  # noqa: E501


        :return: The location_item of this ItemDomainMachineDesignAllOf.  # noqa: E501
        :rtype: ItemDomainLocation
        """
        return self._location_item

    @location_item.setter
    def location_item(self, location_item):
        """Sets the location_item of this ItemDomainMachineDesignAllOf.


        :param location_item: The location_item of this ItemDomainMachineDesignAllOf.  # noqa: E501
        :type: ItemDomainLocation
        """

        self._location_item = location_item

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ItemDomainMachineDesignAllOf):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, ItemDomainMachineDesignAllOf):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Component Database API

    The API that provides access to Component Database data.  # noqa: E501

    The version of the OpenAPI document: 3.15.4
    Contact: djarosz@anl.gov
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from cdbApi.configuration import Configuration


class UpdateCableDesignAssignedItemInformation(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'cd_item_id': 'int',
        'cable_type_id': 'int',
        'cable_type_name': 'str',
        'inventory_id': 'int',
        'inventory_tag': 'str',
        'is_installed': 'bool'
    }

    attribute_map = {
        'cd_item_id': 'cdItemId',
        'cable_type_id': 'cableTypeId',
        'cable_type_name': 'cableTypeName',
        'inventory_id': 'inventoryId',
        'inventory_tag': 'inventoryTag',
        'is_installed': 'isInstalled'
    }

    def __init__(self, cd_item_id=None, cable_type_id=None, cable_type_name=None, inventory_id=None, inventory_tag=None, is_installed=None, local_vars_configuration=None):  # noqa: E501
        """UpdateCableDesignAssignedItemInformation - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._cd_item_id = None
        self._cable_type_id = None
        self._cable_type_name = None
        self._inventory_id = None
        self._inventory_tag = None
        self._is_installed = None
        self.discriminator = None

        if cd_item_id is not None:
            self.cd_item_id = cd_item_id
        if cable_type_id is not None:
            self.cable_type_id = cable_type_id
        if cable_type_name is not None:
            self.cable_type_name = cable_type_name
        if inventory_id is not None:
            self.inventory_id = inventory_id
        if inventory_tag is not None:
            self.inventory_tag = inventory_tag
        if is_installed is not None:
            self.is_installed = is_installed

    @property
    def cd_item_id(self):
        """Gets the cd_item_id of this UpdateCableDesignAssignedItemInformation.  # noqa: E501


        :return: The cd_item_id of this UpdateCableDesignAssignedItemInformation.  # noqa: E501
        :rtype: int
        """
        return self._cd_item_id

    @cd_item_id.setter
    def cd_item_id(self, cd_item_id):
        """Sets the cd_item_id of this UpdateCableDesignAssignedItemInformation.


        :param cd_item_id: The cd_item_id of this UpdateCableDesignAssignedItemInformation.  # noqa: E501
        :type: int
        """

        self._cd_item_id = cd_item_id

    @property
    def cable_type_id(self):
        """Gets the cable_type_id of this UpdateCableDesignAssignedItemInformation.  # noqa: E501


        :return: The cable_type_id of this UpdateCableDesignAssignedItemInformation.  # noqa: E501
        :rtype: int
        """
        return self._cable_type_id

    @cable_type_id.setter
    def cable_type_id(self, cable_type_id):
        """Sets the cable_type_id of this UpdateCableDesignAssignedItemInformation.


        :param cable_type_id: The cable_type_id of this UpdateCableDesignAssignedItemInformation.  # noqa: E501
        :type: int
        """

        self._cable_type_id = cable_type_id

    @property
    def cable_type_name(self):
        """Gets the cable_type_name of this UpdateCableDesignAssignedItemInformation.  # noqa: E501


        :return: The cable_type_name of this UpdateCableDesignAssignedItemInformation.  # noqa: E501
        :rtype: str
        """
        return self._cable_type_name

    @cable_type_name.setter
    def cable_type_name(self, cable_type_name):
        """Sets the cable_type_name of this UpdateCableDesignAssignedItemInformation.


        :param cable_type_name: The cable_type_name of this UpdateCableDesignAssignedItemInformation.  # noqa: E501
        :type: str
        """

        self._cable_type_name = cable_type_name

    @property
    def inventory_id(self):
        """Gets the inventory_id of this UpdateCableDesignAssignedItemInformation.  # noqa: E501


        :return: The inventory_id of this UpdateCableDesignAssignedItemInformation.  # noqa: E501
        :rtype: int
        """
        return self._inventory_id

    @inventory_id.setter
    def inventory_id(self, inventory_id):
        """Sets the inventory_id of this UpdateCableDesignAssignedItemInformation.


        :param inventory_id: The inventory_id of this UpdateCableDesignAssignedItemInformation.  # noqa: E501
        :type: int
        """

        self._inventory_id = inventory_id

    @property
    def inventory_tag(self):
        """Gets the inventory_tag of this UpdateCableDesignAssignedItemInformation.  # noqa: E501


        :return: The inventory_tag of this UpdateCableDesignAssignedItemInformation.  # noqa: E501
        :rtype: str
        """
        return self._inventory_tag

    @inventory_tag.setter
    def inventory_tag(self, inventory_tag):
        """Sets the inventory_tag of this UpdateCableDesignAssignedItemInformation.


        :param inventory_tag: The inventory_tag of this UpdateCableDesignAssignedItemInformation.  # noqa: E501
        :type: str
        """

        self._inventory_tag = inventory_tag

    @property
    def is_installed(self):
        """Gets the is_installed of this UpdateCableDesignAssignedItemInformation.  # noqa: E501


        :return: The is_installed of this UpdateCableDesignAssignedItemInformation.  # noqa: E501
        :rtype: bool
        """
        return self._is_installed

    @is_installed.setter
    def is_installed(self, is_installed):
        """Sets the is_installed of this UpdateCableDesignAssignedItemInformation.


        :param is_installed: The is_installed of this UpdateCableDesignAssignedItemInformation.  # noqa: E501
        :type: bool
        """

        self._is_installed = is_installed

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, UpdateCableDesignAssignedItemInformation):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, UpdateCableDesignAssignedItemInformation):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Component Database API

    The API that provides access to Component Database data.  # noqa: E501

    The version of the OpenAPI document: 3.15.4
    Contact: djarosz@anl.gov
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from cdbApi.configuration import Configuration


class ConciseItem(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'name': 'str',
        'id': 'int',
        'item_identifier1': 'str',
        'item_identifier2': 'str',
        'qr_id': 'int',
        'derived_from_item_id': 'int',
        'derived_from_item_name': 'str',
        'item_project_id_list': 'list[int]',
        'item_type_id_list': 'list[int]',
        'item_category_id_list': 'list[int]',
        'primary_image_for_item': 'str'
    }

    attribute_map = {
        'name': 'name',
        'id': 'id',
        'item_identifier1': 'itemIdentifier1',
        'item_identifier2': 'itemIdentifier2',
        'qr_id': 'qrId',
        'derived_from_item_id': 'derivedFromItemId',
        'derived_from_item_name': 'derivedFromItemName',
        'item_project_id_list': 'itemProjectIdList',
        'item_type_id_list': 'itemTypeIdList',
        'item_category_id_list': 'itemCategoryIdList',
        'primary_image_for_item': 'primaryImageForItem'
    }

    def __init__(self, name=None, id=None, item_identifier1=None, item_identifier2=None, qr_id=None, derived_from_item_id=None, derived_from_item_name=None, item_project_id_list=None, item_type_id_list=None, item_category_id_list=None, primary_image_for_item=None, local_vars_configuration=None):  # noqa: E501
        """ConciseItem - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._name = None
        self._id = None
        self._item_identifier1 = None
        self._item_identifier2 = None
        self._qr_id = None
        self._derived_from_item_id = None
        self._derived_from_item_name = None
        self._item_project_id_list = None
        self._item_type_id_list = None
        self._item_category_id_list = None
        self._primary_image_for_item = None
        self.discriminator = None

        if name is not None:
            self.name = name
        if id is not None:
            self.id = id
        if item_identifier1 is not None:
            self.item_identifier1 = item_identifier1
        if item_identifier2 is not None:
            self.item_identifier2 = item_identifier2
        if qr_id is not None:
            self.qr_id = qr_id
        if derived_from_item_id is not None:
            self.derived_from_item_id = derived_from_item_id
        if derived_from_item_name is not None:
            self.derived_from_item_name = derived_from_item_name
        if item_project_id_list is not None:
            self.item_project_id_list = item_project_id_list
        if item_type_id_list is not None:
            self.item_type_id_list = item_type_id_list
        if item_category_id_list is not None:
            self.item_category_id_list = item_category_id_list
        if primary_image_for_item is not None:
            self.primary_image_for_item = primary_image_for_item

    @property
    def name(self):
        """Gets the name of this ConciseItem.  # noqa: E501


        :return: The name of this ConciseItem.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this ConciseItem.


        :param name: The name of this ConciseItem.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def id(self):
        """Gets the id of this ConciseItem.  # noqa: E501


        :return: The id of this ConciseItem.  # noqa: E501
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this ConciseItem.


        :param id: The id of this ConciseItem.  # noqa: E501
        :type: int
        """

        self._id = id

    @property
    def item_identifier1(self):
        """Gets the item_identifier1 of this ConciseItem.  # noqa: E501


        :return: The item_identifier1 of this ConciseItem.  # noqa: E501
        :rtype: str
        """
        return self._item_identifier1

    @item_identifier1.setter
    def item_identifier1(self, item_identifier1):
        """Sets the item_identifier1 of this ConciseItem.


        :param item_identifier1: The item_identifier1 of this ConciseItem.  # noqa: E501
        :type: str
        """

        self._item_identifier1 = item_identifier1

    @property
    def item_identifier2(self):
        """Gets the item_identifier2 of this ConciseItem.  # noqa: E501


        :return: The item_identifier2 of this ConciseItem.  # noqa: E501
        :rtype: str
        """
        return self._item_identifier2

    @item_identifier2.setter
    def item_identifier2(self, item_identifier2):
        """Sets the item_identifier2 of this ConciseItem.


        :param item_identifier2: The item_identifier2 of this ConciseItem.  # noqa: E501
        :type: str
        """

        self._item_identifier2 = item_identifier2

    @property
    def qr_id(self):
        """Gets the qr_id of this ConciseItem.  # noqa: E501


        :return: The qr_id of this ConciseItem.  # noqa: E501
        :rtype: int
        """
        return self._qr_id

    @qr_id.setter
    def qr_id(self, qr_id):
        """Sets the qr_id of this ConciseItem.


        :param qr_id: The qr_id of this ConciseItem.  # noqa: E501
        :type: int
        """

        self._qr_id = qr_id

    @property
    def derived_from_item_id(self):
        """Gets the derived_from_item_id of this ConciseItem.  # noqa: E501


        :return: The derived_from_item_id of this ConciseItem.  # noqa: E501
        :rtype: int
        """
        return self._derived_from_item_id

    @derived_from_item_id.setter
    def derived_from_item_id(self, derived_from_item_id):
        """Sets the derived_from_item_id of this ConciseItem.


        :param derived_from_item_id: The derived_from_item_id of this ConciseItem.  # noqa: E501
        :type: int
        """

        self._derived_from_item_id = derived_from_item_id

    @property
    def derived_from_item_name(self):
        """Gets the derived_from_item_name of this ConciseItem.  # noqa: E501


        :return: The derived_from_item_name of this ConciseItem.  # noqa: E501
        :rtype: str
        """
        return self._derived_from_item_name

    @derived_from_item_name.setter
    def derived_from_item_name(self, derived_from_item_name):
        """Sets the derived_from_item_name of this ConciseItem.


        :param derived_from_item_name: The derived_from_item_name of this ConciseItem.  # noqa: E501
        :type: str
        """

        self._derived_from_item_name = derived_from_item_name

    @property
    def item_project_id_list(self):
        """Gets the item_project_id_list of this ConciseItem.  # noqa: E501


        :return: The item_project_id_list of this ConciseItem.  # noqa: E501
        :rtype: list[int]
        """
        return self._item_project_id_list

    @item_project_id_list.setter
    def item_project_id_list(self, item_project_id_list):
        """Sets the item_project_id_list of this ConciseItem.


        :param item_project_id_list: The item_project_id_list of this ConciseItem.  # noqa: E501
        :type: list[int]
        """

        self._item_project_id_list = item_project_id_list

    @property
    def item_type_id_list(self):
        """Gets the item_type_id_list of this ConciseItem.  # noqa: E501


        :return: The item_type_id_list of this ConciseItem.  # noqa: E501
        :rtype: list[int]
        """
        return self._item_type_id_list

    @item_type_id_list.setter
    def item_type_id_list(self, item_type_id_list):
        """Sets the item_type_id_list of this ConciseItem.


        :param item_type_id_list: The item_type_id_list of this ConciseItem.  # noqa: E501
        :type: list[int]
        """

        self._item_type_id_list = item_type_id_list

    @property
    def item_category_id_list(self):
        """Gets the item_category_id_list of this ConciseItem.  # noqa: E501


        :return: The item_category_id_list of this ConciseItem.  # noqa: E501
        :rtype: list[int]
        """
        return self._item_category_id_list

    @item_category_id_list.setter
    def item_category_id_list(self, item_category_id_list):
        """Sets the item_category_id_list of this ConciseItem.


        :param item_category_id_list: The item_category_id_list of this ConciseItem.  # noqa: E501
        :type: list[int]
        """

        self._item_category_id_list = item_category_id_list

    @property
    def primary_image_for_item(self):
        """Gets the primary_image_for_item of this ConciseItem.  # noqa: E501


        :return: The primary_image_for_item of this ConciseItem.  # noqa: E501
        :rtype: str
        """
        return self._primary_image_for_item

    @primary_image_for_item.setter
    def primary_image_for_item(self, primary_image_for_item):
        """Sets the primary_image_for_item of this ConciseItem.


        :param primary_image_for_item: The primary_image_for_item of this ConciseItem.  # noqa: E501
        :type: str
        """

        self._primary_image_for_item = primary_image_for_item

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ConciseItem):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, ConciseItem):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Component Database API

    The API that provides access to Component Database data.  # noqa: E501

    The version of the OpenAPI document: 3.15.4
    Contact: djarosz@anl.gov
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from cdbApi.configuration import Configuration


class PromoteMachineElementInformation(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'parent_md_item_id': 'int',
        'assembly_element_id': 'int',
        'new_name': 'str'
    }

    attribute_map = {
        'parent_md_item_id': 'parentMdItemId',
        'assembly_element_id': 'assemblyElementId',
        'new_name': 'newName'
    }

    def __init__(self, parent_md_item_id=None, assembly_element_id=None, new_name=None, local_vars_configuration=None):  # noqa: E501
        """PromoteMachineElementInformation - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._parent_md_item_id = None
        self._assembly_element_id = None
        self._new_name = None
        self.discriminator = None

        if parent_md_item_id is not None:
            self.parent_md_item_id = parent_md_item_id
        if assembly_element_id is not None:
            self.assembly_element_id = assembly_element_id
        if new_name is not None:
            self.new_name = new_name

    @property
    def parent_md_item_id(self):
        """Gets the parent_md_item_id of this PromoteMachineElementInformation.  # noqa: E501


        :return: The parent_md_item_id of this PromoteMachineElementInformation.  # noqa: E501
        :rtype: int
        """
        return self._parent_md_item_id

    @parent_md_item_id.setter
    def parent_md_item_id(self, parent_md_item_id):
        """Sets the parent_md_item_id of this PromoteMachineElementInformation.


        :param parent_md_item_id: The parent_md_item_id of this PromoteMachineElementInformation.  # noqa: E501
        :type: int
        """

        self._parent_md_item_id = parent_md_item_id

    @property
    def assembly_element_id(self):
        """Gets the assembly_element_id of this PromoteMachineElementInformation.  # noqa: E501


        :return: The assembly_element_id of this PromoteMachineElementInformation.  # noqa: E501
        :rtype: int
        """
        return self._assembly_element_id

    @assembly_element_id.setter
    def assembly_element_id(self, assembly_element_id):
        """Sets the assembly_element_id of this PromoteMachineElementInformation.


        :param assembly_element_id: The assembly_element_id of this PromoteMachineElementInformation.  # noqa: E501
        :type: int
        """

        self._assembly_element_id = assembly_element_id

    @property
    def new_name(self):
        """Gets the new_name of this PromoteMachineElementInformation.  # noqa: E501


        :return: The new_name of this PromoteMachineElementInformation.  # noqa: E501
        :rtype: str
        """
        return self._new_name

    @new_name.setter
    def new_name(self, new_name):
        """Sets the new_name of this PromoteMachineElementInformation.


        :param new_name: The new_name of this PromoteMachineElementInformation.  # noqa: E501
        :type: str
        """

        self._new_name = new_name

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PromoteMachineElementInformation):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, PromoteMachineElementInformation):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Component Database API

    The API that provides access to Component Database data.  # noqa: E501

    The version of the OpenAPI document: 3.15.4
    Contact: djarosz@anl.gov
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from cdbApi.api_client import ApiClient
from cdbApi.exceptions import (  # noqa: F401
    ApiTypeError,
    ApiValueError
)


class ConnectorTypesApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def get_connector_type_by_id(self, id, **kwargs):  # noqa: E501
        """get_connector_type_by_id  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_connector_type_by_id(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param int id: (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: ConnectorType
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.get_connector_type_by_id_with_http_info(id, **kwargs)  # noqa: E501

    def get_connector_type_by_id_with_http_info(self, id, **kwargs):  # noqa: E501
        """get_connector_type_by_id  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_connector_type_by_id_with_http_info(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param int id: (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(ConnectorType, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'id'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_connector_type_by_id" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'id' is set
        if self.api_client.client_side_validation and ('id' not in local_var_params or  # noqa: E501
                                                        local_var_params['id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `id` when calling `get_connector_type_by_id`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'id' in local_var_params:
            path_params['id'] = local_var_params['id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/ConnectorTypes/ById/{id}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ConnectorType',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_connector_type_by_name(self, name, **kwargs):  # noqa: E501
        """get_connector_type_by_name  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_connector_type_by_name(name, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str name: (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: ConnectorType
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.get_connector_type_by_name_with_http_info(name, **kwargs)  # noqa: E501

    def get_connector_type_by_name_with_http_info(self, name, **kwargs):  # noqa: E501
        """get_connector_type_by_name  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_connector_type_by_name_with_http_info(name, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str name: (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(ConnectorType, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'name'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_connector_type_by_name" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'name' is set
        if self.api_client.client_side_validation and ('name' not in local_var_params or  # noqa: E501
                                                        local_var_params['name'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `name` when calling `get_connector_type_by_name`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'name' in local_var_params:
            path_params['name'] = local_var_params['name']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/ConnectorTypes/ByName/{name}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ConnectorType',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_connector_type_id_list(self, connector_type_id_list_request, **kwargs):  # noqa: E501
        """get_connector_type_id_list  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_connector_type_id_list(connector_type_id_list_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param ConnectorTypeIdListRequest connector_type_id_list_request: (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: list[int]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.get_connector_type_id_list_with_http_info(connector_type_id_list_request, **kwargs)  # noqa: E501

    def get_connector_type_id_list_with_http_info(self, connector_type_id_list_request, **kwargs):  # noqa: E501
        """get_connector_type_id_list  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_connector_type_id_list_with_http_info(connector_type_id_list_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param ConnectorTypeIdListRequest connector_type_id_list_request: (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(list[int], status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'connector_type_id_list_request'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_connector_type_id_list" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'connector_type_id_list_request' is set
        if self.api_client.client_side_validation and ('connector_type_id_list_request' not in local_var_params or  # noqa: E501
                                                        local_var_params['connector_type_id_list_request'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `connector_type_id_list_request` when calling `get_connector_type_id_list`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'connector_type_id_list_request' in local_var_params:
            body_params = local_var_params['connector_type_id_list_request']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/ConnectorTypes/IdList', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[int]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_connector_type_list(self, **kwargs):  # noqa: E501
        """get_connector_type_list  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_connector_type_list(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: list[ConnectorType]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.get_connector_type_list_with_http_info(**kwargs)  # noqa: E501

    def get_connector_type_list_with_http_info(self, **kwargs):  # noqa: E501
        """get_connector_type_list  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_connector_type_list_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(list[ConnectorType], status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_connector_type_list" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/ConnectorTypes/all', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[ConnectorType]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)



#!/usr/bin/env python

"""
Copyright (c) UChicago Argonne, LLC. All rights reserved.
See LICENSE file.
"""

"""
DEV NOTE: To publish API
# Update version in this file
python3 setup-api.py sdist
twine upload dist/(specific version file)
"""

from setuptools import setup
from setuptools import find_packages

setup(name='ComponentDB-API',
      version='3.15.5.dev1',
      packages=["cdbApi",
                "cdbApi.api",
                "cdbApi.models"],
      py_modules=["CdbApiFactory"],
      install_requires=['python-dateutil', 
          'urllib3',
          'certifi',
          'six'],
      license='Copyright (c) UChicago Argonne, LLC. All rights reserved.',
      description='Python APIs used to communicate with java hosted ComponentDB API.',
      maintainer='Dariusz Jarosz',
      maintainer_email='djarosz@aps.anl.gov',
      url='https://github.com/AdvancedPhotonSource/ComponentDB',
      entry_points={
        'console_scripts': [
          'cdb-python-client-test = CdbApiFactory:run_command'
        ]
      })



# coding: utf-8

"""
    Component Database API

    The API that provides access to Component Database data.  # noqa: E501

    The version of the OpenAPI document: 3.15.4
    Contact: djarosz@anl.gov
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from cdbApi.configuration import Configuration


class Log(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'id': 'int',
        'text': 'str',
        'entered_on_date_time': 'datetime',
        'effective_from_date_time': 'datetime',
        'effective_to_date_time': 'datetime',
        'entered_by_username': 'str'
    }

    attribute_map = {
        'id': 'id',
        'text': 'text',
        'entered_on_date_time': 'enteredOnDateTime',
        'effective_from_date_time': 'effectiveFromDateTime',
        'effective_to_date_time': 'effectiveToDateTime',
        'entered_by_username': 'enteredByUsername'
    }

    def __init__(self, id=None, text=None, entered_on_date_time=None, effective_from_date_time=None, effective_to_date_time=None, entered_by_username=None, local_vars_configuration=None):  # noqa: E501
        """Log - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._id = None
        self._text = None
        self._entered_on_date_time = None
        self._effective_from_date_time = None
        self._effective_to_date_time = None
        self._entered_by_username = None
        self.discriminator = None

        if id is not None:
            self.id = id
        self.text = text
        self.entered_on_date_time = entered_on_date_time
        if effective_from_date_time is not None:
            self.effective_from_date_time = effective_from_date_time
        if effective_to_date_time is not None:
            self.effective_to_date_time = effective_to_date_time
        if entered_by_username is not None:
            self.entered_by_username = entered_by_username

    @property
    def id(self):
        """Gets the id of this Log.  # noqa: E501


        :return: The id of this Log.  # noqa: E501
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this Log.


        :param id: The id of this Log.  # noqa: E501
        :type: int
        """

        self._id = id

    @property
    def text(self):
        """Gets the text of this Log.  # noqa: E501


        :return: The text of this Log.  # noqa: E501
        :rtype: str
        """
        return self._text

    @text.setter
    def text(self, text):
        """Sets the text of this Log.


        :param text: The text of this Log.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and text is None:  # noqa: E501
            raise ValueError("Invalid value for `text`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                text is not None and len(text) > 65535):
            raise ValueError("Invalid value for `text`, length must be less than or equal to `65535`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                text is not None and len(text) < 0):
            raise ValueError("Invalid value for `text`, length must be greater than or equal to `0`")  # noqa: E501

        self._text = text

    @property
    def entered_on_date_time(self):
        """Gets the entered_on_date_time of this Log.  # noqa: E501


        :return: The entered_on_date_time of this Log.  # noqa: E501
        :rtype: datetime
        """
        return self._entered_on_date_time

    @entered_on_date_time.setter
    def entered_on_date_time(self, entered_on_date_time):
        """Sets the entered_on_date_time of this Log.


        :param entered_on_date_time: The entered_on_date_time of this Log.  # noqa: E501
        :type: datetime
        """
        if self.local_vars_configuration.client_side_validation and entered_on_date_time is None:  # noqa: E501
            raise ValueError("Invalid value for `entered_on_date_time`, must not be `None`")  # noqa: E501

        self._entered_on_date_time = entered_on_date_time

    @property
    def effective_from_date_time(self):
        """Gets the effective_from_date_time of this Log.  # noqa: E501


        :return: The effective_from_date_time of this Log.  # noqa: E501
        :rtype: datetime
        """
        return self._effective_from_date_time

    @effective_from_date_time.setter
    def effective_from_date_time(self, effective_from_date_time):
        """Sets the effective_from_date_time of this Log.


        :param effective_from_date_time: The effective_from_date_time of this Log.  # noqa: E501
        :type: datetime
        """

        self._effective_from_date_time = effective_from_date_time

    @property
    def effective_to_date_time(self):
        """Gets the effective_to_date_time of this Log.  # noqa: E501


        :return: The effective_to_date_time of this Log.  # noqa: E501
        :rtype: datetime
        """
        return self._effective_to_date_time

    @effective_to_date_time.setter
    def effective_to_date_time(self, effective_to_date_time):
        """Sets the effective_to_date_time of this Log.


        :param effective_to_date_time: The effective_to_date_time of this Log.  # noqa: E501
        :type: datetime
        """

        self._effective_to_date_time = effective_to_date_time

    @property
    def entered_by_username(self):
        """Gets the entered_by_username of this Log.  # noqa: E501


        :return: The entered_by_username of this Log.  # noqa: E501
        :rtype: str
        """
        return self._entered_by_username

    @entered_by_username.setter
    def entered_by_username(self, entered_by_username):
        """Sets the entered_by_username of this Log.


        :param entered_by_username: The entered_by_username of this Log.  # noqa: E501
        :type: str
        """

        self._entered_by_username = entered_by_username

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Log):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, Log):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Component Database API

    The API that provides access to Component Database data.  # noqa: E501

    The version of the OpenAPI document: 3.15.4
    Contact: djarosz@anl.gov
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from cdbApi.configuration import Configuration


class NewControlRelationshipInformation(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'controlled_machine_id': 'int',
        'controlling_machine_id': 'int',
        'linked_parent_machine_relationship_id': 'int',
        'control_interface_to_parent': 'str'
    }

    attribute_map = {
        'controlled_machine_id': 'controlledMachineId',
        'controlling_machine_id': 'controllingMachineId',
        'linked_parent_machine_relationship_id': 'linkedParentMachineRelationshipId',
        'control_interface_to_parent': 'controlInterfaceToParent'
    }

    def __init__(self, controlled_machine_id=None, controlling_machine_id=None, linked_parent_machine_relationship_id=None, control_interface_to_parent=None, local_vars_configuration=None):  # noqa: E501
        """NewControlRelationshipInformation - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._controlled_machine_id = None
        self._controlling_machine_id = None
        self._linked_parent_machine_relationship_id = None
        self._control_interface_to_parent = None
        self.discriminator = None

        if controlled_machine_id is not None:
            self.controlled_machine_id = controlled_machine_id
        if controlling_machine_id is not None:
            self.controlling_machine_id = controlling_machine_id
        if linked_parent_machine_relationship_id is not None:
            self.linked_parent_machine_relationship_id = linked_parent_machine_relationship_id
        if control_interface_to_parent is not None:
            self.control_interface_to_parent = control_interface_to_parent

    @property
    def controlled_machine_id(self):
        """Gets the controlled_machine_id of this NewControlRelationshipInformation.  # noqa: E501


        :return: The controlled_machine_id of this NewControlRelationshipInformation.  # noqa: E501
        :rtype: int
        """
        return self._controlled_machine_id

    @controlled_machine_id.setter
    def controlled_machine_id(self, controlled_machine_id):
        """Sets the controlled_machine_id of this NewControlRelationshipInformation.


        :param controlled_machine_id: The controlled_machine_id of this NewControlRelationshipInformation.  # noqa: E501
        :type: int
        """

        self._controlled_machine_id = controlled_machine_id

    @property
    def controlling_machine_id(self):
        """Gets the controlling_machine_id of this NewControlRelationshipInformation.  # noqa: E501


        :return: The controlling_machine_id of this NewControlRelationshipInformation.  # noqa: E501
        :rtype: int
        """
        return self._controlling_machine_id

    @controlling_machine_id.setter
    def controlling_machine_id(self, controlling_machine_id):
        """Sets the controlling_machine_id of this NewControlRelationshipInformation.


        :param controlling_machine_id: The controlling_machine_id of this NewControlRelationshipInformation.  # noqa: E501
        :type: int
        """

        self._controlling_machine_id = controlling_machine_id

    @property
    def linked_parent_machine_relationship_id(self):
        """Gets the linked_parent_machine_relationship_id of this NewControlRelationshipInformation.  # noqa: E501


        :return: The linked_parent_machine_relationship_id of this NewControlRelationshipInformation.  # noqa: E501
        :rtype: int
        """
        return self._linked_parent_machine_relationship_id

    @linked_parent_machine_relationship_id.setter
    def linked_parent_machine_relationship_id(self, linked_parent_machine_relationship_id):
        """Sets the linked_parent_machine_relationship_id of this NewControlRelationshipInformation.


        :param linked_parent_machine_relationship_id: The linked_parent_machine_relationship_id of this NewControlRelationshipInformation.  # noqa: E501
        :type: int
        """

        self._linked_parent_machine_relationship_id = linked_parent_machine_relationship_id

    @property
    def control_interface_to_parent(self):
        """Gets the control_interface_to_parent of this NewControlRelationshipInformation.  # noqa: E501


        :return: The control_interface_to_parent of this NewControlRelationshipInformation.  # noqa: E501
        :rtype: str
        """
        return self._control_interface_to_parent

    @control_interface_to_parent.setter
    def control_interface_to_parent(self, control_interface_to_parent):
        """Sets the control_interface_to_parent of this NewControlRelationshipInformation.


        :param control_interface_to_parent: The control_interface_to_parent of this NewControlRelationshipInformation.  # noqa: E501
        :type: str
        """

        self._control_interface_to_parent = control_interface_to_parent

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, NewControlRelationshipInformation):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, NewControlRelationshipInformation):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Component Database API

    The API that provides access to Component Database data.  # noqa: E501

    The version of the OpenAPI document: 3.15.4
    Contact: djarosz@anl.gov
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from cdbApi.api_client import ApiClient
from cdbApi.exceptions import (  # noqa: F401
    ApiTypeError,
    ApiValueError
)


class CableDesignItemsApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def clear_assigned_inventory(self, update_cable_design_assigned_item_information, **kwargs):  # noqa: E501
        """Clear assigned inventory and installation status for cable design item given cable design id. Cable design will retain existing cable type.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.clear_assigned_inventory(update_cable_design_assigned_item_information, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param UpdateCableDesignAssignedItemInformation update_cable_design_assigned_item_information: (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: ItemDomainCableDesign
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.clear_assigned_inventory_with_http_info(update_cable_design_assigned_item_information, **kwargs)  # noqa: E501

    def clear_assigned_inventory_with_http_info(self, update_cable_design_assigned_item_information, **kwargs):  # noqa: E501
        """Clear assigned inventory and installation status for cable design item given cable design id. Cable design will retain existing cable type.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.clear_assigned_inventory_with_http_info(update_cable_design_assigned_item_information, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param UpdateCableDesignAssignedItemInformation update_cable_design_assigned_item_information: (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(ItemDomainCableDesign, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'update_cable_design_assigned_item_information'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method clear_assigned_inventory" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'update_cable_design_assigned_item_information' is set
        if self.api_client.client_side_validation and ('update_cable_design_assigned_item_information' not in local_var_params or  # noqa: E501
                                                        local_var_params['update_cable_design_assigned_item_information'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `update_cable_design_assigned_item_information` when calling `clear_assigned_inventory`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'update_cable_design_assigned_item_information' in local_var_params:
            body_params = local_var_params['update_cable_design_assigned_item_information']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['cdbAuth']  # noqa: E501

        return self.api_client.call_api(
            '/api/CableDesignItems/ClearAssignedInventory', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ItemDomainCableDesign',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def clear_cable_type(self, update_cable_design_assigned_item_information, **kwargs):  # noqa: E501
        """Clear cable type for cable design item given cable design id.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.clear_cable_type(update_cable_design_assigned_item_information, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param UpdateCableDesignAssignedItemInformation update_cable_design_assigned_item_information: (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: ItemDomainCableDesign
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.clear_cable_type_with_http_info(update_cable_design_assigned_item_information, **kwargs)  # noqa: E501

    def clear_cable_type_with_http_info(self, update_cable_design_assigned_item_information, **kwargs):  # noqa: E501
        """Clear cable type for cable design item given cable design id.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.clear_cable_type_with_http_info(update_cable_design_assigned_item_information, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param UpdateCableDesignAssignedItemInformation update_cable_design_assigned_item_information: (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(ItemDomainCableDesign, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'update_cable_design_assigned_item_information'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method clear_cable_type" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'update_cable_design_assigned_item_information' is set
        if self.api_client.client_side_validation and ('update_cable_design_assigned_item_information' not in local_var_params or  # noqa: E501
                                                        local_var_params['update_cable_design_assigned_item_information'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `update_cable_design_assigned_item_information` when calling `clear_cable_type`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'update_cable_design_assigned_item_information' in local_var_params:
            body_params = local_var_params['update_cable_design_assigned_item_information']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['cdbAuth']  # noqa: E501

        return self.api_client.call_api(
            '/api/CableDesignItems/ClearCableType', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ItemDomainCableDesign',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_cable_design_connection_list(self, cable_design_id, **kwargs):  # noqa: E501
        """get_cable_design_connection_list  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_cable_design_connection_list(cable_design_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param int cable_design_id: (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: list[CableDesignConnectionListObject]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.get_cable_design_connection_list_with_http_info(cable_design_id, **kwargs)  # noqa: E501

    def get_cable_design_connection_list_with_http_info(self, cable_design_id, **kwargs):  # noqa: E501
        """get_cable_design_connection_list  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_cable_design_connection_list_with_http_info(cable_design_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param int cable_design_id: (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(list[CableDesignConnectionListObject], status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'cable_design_id'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_cable_design_connection_list" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'cable_design_id' is set
        if self.api_client.client_side_validation and ('cable_design_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['cable_design_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `cable_design_id` when calling `get_cable_design_connection_list`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'cable_design_id' in local_var_params:
            path_params['cableDesignId'] = local_var_params['cable_design_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/CableDesignItems/ConnectionList/{cableDesignId}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[CableDesignConnectionListObject]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_cable_design_id_list(self, item_domain_cable_design_id_list_request, **kwargs):  # noqa: E501
        """get_cable_design_id_list  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_cable_design_id_list(item_domain_cable_design_id_list_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param ItemDomainCableDesignIdListRequest item_domain_cable_design_id_list_request: (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: list[int]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.get_cable_design_id_list_with_http_info(item_domain_cable_design_id_list_request, **kwargs)  # noqa: E501

    def get_cable_design_id_list_with_http_info(self, item_domain_cable_design_id_list_request, **kwargs):  # noqa: E501
        """get_cable_design_id_list  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_cable_design_id_list_with_http_info(item_domain_cable_design_id_list_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param ItemDomainCableDesignIdListRequest item_domain_cable_design_id_list_request: (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(list[int], status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'item_domain_cable_design_id_list_request'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_cable_design_id_list" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'item_domain_cable_design_id_list_request' is set
        if self.api_client.client_side_validation and ('item_domain_cable_design_id_list_request' not in local_var_params or  # noqa: E501
                                                        local_var_params['item_domain_cable_design_id_list_request'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `item_domain_cable_design_id_list_request` when calling `get_cable_design_id_list`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'item_domain_cable_design_id_list_request' in local_var_params:
            body_params = local_var_params['item_domain_cable_design_id_list_request']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/CableDesignItems/IdList', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[int]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_cable_design_item_by_id(self, id, **kwargs):  # noqa: E501
        """get_cable_design_item_by_id  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_cable_design_item_by_id(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param int id: (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: ItemDomainCableDesign
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.get_cable_design_item_by_id_with_http_info(id, **kwargs)  # noqa: E501

    def get_cable_design_item_by_id_with_http_info(self, id, **kwargs):  # noqa: E501
        """get_cable_design_item_by_id  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_cable_design_item_by_id_with_http_info(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param int id: (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(ItemDomainCableDesign, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'id'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_cable_design_item_by_id" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'id' is set
        if self.api_client.client_side_validation and ('id' not in local_var_params or  # noqa: E501
                                                        local_var_params['id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `id` when calling `get_cable_design_item_by_id`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'id' in local_var_params:
            path_params['id'] = local_var_params['id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/CableDesignItems/ById/{id}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ItemDomainCableDesign',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_cable_design_item_by_name(self, name, **kwargs):  # noqa: E501
        """get_cable_design_item_by_name  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_cable_design_item_by_name(name, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str name: (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: ItemDomainCableDesign
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.get_cable_design_item_by_name_with_http_info(name, **kwargs)  # noqa: E501

    def get_cable_design_item_by_name_with_http_info(self, name, **kwargs):  # noqa: E501
        """get_cable_design_item_by_name  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_cable_design_item_by_name_with_http_info(name, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str name: (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(ItemDomainCableDesign, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'name'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_cable_design_item_by_name" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'name' is set
        if self.api_client.client_side_validation and ('name' not in local_var_params or  # noqa: E501
                                                        local_var_params['name'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `name` when calling `get_cable_design_item_by_name`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'name' in local_var_params:
            path_params['name'] = local_var_params['name']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/CableDesignItems/ByName/{name}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ItemDomainCableDesign',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_cable_design_item_list(self, **kwargs):  # noqa: E501
        """get_cable_design_item_list  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_cable_design_item_list(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: list[ItemDomainCableDesign]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.get_cable_design_item_list_with_http_info(**kwargs)  # noqa: E501

    def get_cable_design_item_list_with_http_info(self, **kwargs):  # noqa: E501
        """get_cable_design_item_list  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_cable_design_item_list_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(list[ItemDomainCableDesign], status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_cable_design_item_list" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/CableDesignItems/all', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[ItemDomainCableDesign]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def update_assigned_inventory_id(self, update_cable_design_assigned_item_information, **kwargs):  # noqa: E501
        """Update assigned inventory and installation status for cable design item given cable design id, inventory item id, and installation status. Note this operation might change the cable design item's cable type if inventory is of different type.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_assigned_inventory_id(update_cable_design_assigned_item_information, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param UpdateCableDesignAssignedItemInformation update_cable_design_assigned_item_information: (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: ItemDomainCableDesign
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.update_assigned_inventory_id_with_http_info(update_cable_design_assigned_item_information, **kwargs)  # noqa: E501

    def update_assigned_inventory_id_with_http_info(self, update_cable_design_assigned_item_information, **kwargs):  # noqa: E501
        """Update assigned inventory and installation status for cable design item given cable design id, inventory item id, and installation status. Note this operation might change the cable design item's cable type if inventory is of different type.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_assigned_inventory_id_with_http_info(update_cable_design_assigned_item_information, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param UpdateCableDesignAssignedItemInformation update_cable_design_assigned_item_information: (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(ItemDomainCableDesign, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'update_cable_design_assigned_item_information'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method update_assigned_inventory_id" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'update_cable_design_assigned_item_information' is set
        if self.api_client.client_side_validation and ('update_cable_design_assigned_item_information' not in local_var_params or  # noqa: E501
                                                        local_var_params['update_cable_design_assigned_item_information'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `update_cable_design_assigned_item_information` when calling `update_assigned_inventory_id`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'update_cable_design_assigned_item_information' in local_var_params:
            body_params = local_var_params['update_cable_design_assigned_item_information']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['cdbAuth']  # noqa: E501

        return self.api_client.call_api(
            '/api/CableDesignItems/UpdateAssignedInventoryId', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ItemDomainCableDesign',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def update_assigned_inventory_name(self, update_cable_design_assigned_item_information, **kwargs):  # noqa: E501
        """Update assigned inventory and installation status for cable design item given cable design id, inventory tag/name, and installation status.  Cable type id or name is optional and if not specified the inventory look up by name uses current cable type.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_assigned_inventory_name(update_cable_design_assigned_item_information, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param UpdateCableDesignAssignedItemInformation update_cable_design_assigned_item_information: (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: ItemDomainCableDesign
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.update_assigned_inventory_name_with_http_info(update_cable_design_assigned_item_information, **kwargs)  # noqa: E501

    def update_assigned_inventory_name_with_http_info(self, update_cable_design_assigned_item_information, **kwargs):  # noqa: E501
        """Update assigned inventory and installation status for cable design item given cable design id, inventory tag/name, and installation status.  Cable type id or name is optional and if not specified the inventory look up by name uses current cable type.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_assigned_inventory_name_with_http_info(update_cable_design_assigned_item_information, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param UpdateCableDesignAssignedItemInformation update_cable_design_assigned_item_information: (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(ItemDomainCableDesign, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'update_cable_design_assigned_item_information'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method update_assigned_inventory_name" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'update_cable_design_assigned_item_information' is set
        if self.api_client.client_side_validation and ('update_cable_design_assigned_item_information' not in local_var_params or  # noqa: E501
                                                        local_var_params['update_cable_design_assigned_item_information'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `update_cable_design_assigned_item_information` when calling `update_assigned_inventory_name`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'update_cable_design_assigned_item_information' in local_var_params:
            body_params = local_var_params['update_cable_design_assigned_item_information']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['cdbAuth']  # noqa: E501

        return self.api_client.call_api(
            '/api/CableDesignItems/UpdateAssignedInventoryName', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ItemDomainCableDesign',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def update_cable_type_id(self, update_cable_design_assigned_item_information, **kwargs):  # noqa: E501
        """Update cable type for cable design item given cable design id and cable type id.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_cable_type_id(update_cable_design_assigned_item_information, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param UpdateCableDesignAssignedItemInformation update_cable_design_assigned_item_information: (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: ItemDomainCableDesign
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.update_cable_type_id_with_http_info(update_cable_design_assigned_item_information, **kwargs)  # noqa: E501

    def update_cable_type_id_with_http_info(self, update_cable_design_assigned_item_information, **kwargs):  # noqa: E501
        """Update cable type for cable design item given cable design id and cable type id.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_cable_type_id_with_http_info(update_cable_design_assigned_item_information, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param UpdateCableDesignAssignedItemInformation update_cable_design_assigned_item_information: (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(ItemDomainCableDesign, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'update_cable_design_assigned_item_information'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method update_cable_type_id" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'update_cable_design_assigned_item_information' is set
        if self.api_client.client_side_validation and ('update_cable_design_assigned_item_information' not in local_var_params or  # noqa: E501
                                                        local_var_params['update_cable_design_assigned_item_information'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `update_cable_design_assigned_item_information` when calling `update_cable_type_id`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'update_cable_design_assigned_item_information' in local_var_params:
            body_params = local_var_params['update_cable_design_assigned_item_information']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['cdbAuth']  # noqa: E501

        return self.api_client.call_api(
            '/api/CableDesignItems/UpdateCableTypeId', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ItemDomainCableDesign',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def update_cable_type_name(self, update_cable_design_assigned_item_information, **kwargs):  # noqa: E501
        """Update cable type for cable design item given cable design id and cable type name.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_cable_type_name(update_cable_design_assigned_item_information, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param UpdateCableDesignAssignedItemInformation update_cable_design_assigned_item_information: (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: ItemDomainCableDesign
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.update_cable_type_name_with_http_info(update_cable_design_assigned_item_information, **kwargs)  # noqa: E501

    def update_cable_type_name_with_http_info(self, update_cable_design_assigned_item_information, **kwargs):  # noqa: E501
        """Update cable type for cable design item given cable design id and cable type name.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_cable_type_name_with_http_info(update_cable_design_assigned_item_information, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param UpdateCableDesignAssignedItemInformation update_cable_design_assigned_item_information: (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(ItemDomainCableDesign, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'update_cable_design_assigned_item_information'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method update_cable_type_name" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'update_cable_design_assigned_item_information' is set
        if self.api_client.client_side_validation and ('update_cable_design_assigned_item_information' not in local_var_params or  # noqa: E501
                                                        local_var_params['update_cable_design_assigned_item_information'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `update_cable_design_assigned_item_information` when calling `update_cable_type_name`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'update_cable_design_assigned_item_information' in local_var_params:
            body_params = local_var_params['update_cable_design_assigned_item_information']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['cdbAuth']  # noqa: E501

        return self.api_client.call_api(
            '/api/CableDesignItems/UpdateCableTypeName', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ItemDomainCableDesign',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def update_installation_status(self, update_cable_design_assigned_item_information, **kwargs):  # noqa: E501
        """Update installation status for cable design item given cable design id and installation status.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_installation_status(update_cable_design_assigned_item_information, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param UpdateCableDesignAssignedItemInformation update_cable_design_assigned_item_information: (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: ItemDomainCableDesign
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.update_installation_status_with_http_info(update_cable_design_assigned_item_information, **kwargs)  # noqa: E501

    def update_installation_status_with_http_info(self, update_cable_design_assigned_item_information, **kwargs):  # noqa: E501
        """Update installation status for cable design item given cable design id and installation status.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_installation_status_with_http_info(update_cable_design_assigned_item_information, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param UpdateCableDesignAssignedItemInformation update_cable_design_assigned_item_information: (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(ItemDomainCableDesign, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'update_cable_design_assigned_item_information'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method update_installation_status" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'update_cable_design_assigned_item_information' is set
        if self.api_client.client_side_validation and ('update_cable_design_assigned_item_information' not in local_var_params or  # noqa: E501
                                                        local_var_params['update_cable_design_assigned_item_information'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `update_cable_design_assigned_item_information` when calling `update_installation_status`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'update_cable_design_assigned_item_information' in local_var_params:
            body_params = local_var_params['update_cable_design_assigned_item_information']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['cdbAuth']  # noqa: E501

        return self.api_client.call_api(
            '/api/CableDesignItems/UpdateInstallationStatus', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ItemDomainCableDesign',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    Component Database API

    The API that provides access to Component Database data.  # noqa: E501

    The version of the OpenAPI document: 3.15.4
    Contact: djarosz@anl.gov
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from cdbApi.configuration import Configuration


class MachineDesignConnectorListObject(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'item_connector': 'ItemConnector',
        'connected_cables': 'list[ItemDomainCableDesign]',
        'connected_items': 'list[Item]',
        'connected_to_items_string': 'str',
        'connected_cables_string': 'str',
        'connector_name': 'str'
    }

    attribute_map = {
        'item_connector': 'itemConnector',
        'connected_cables': 'connectedCables',
        'connected_items': 'connectedItems',
        'connected_to_items_string': 'connectedToItemsString',
        'connected_cables_string': 'connectedCablesString',
        'connector_name': 'connectorName'
    }

    def __init__(self, item_connector=None, connected_cables=None, connected_items=None, connected_to_items_string=None, connected_cables_string=None, connector_name=None, local_vars_configuration=None):  # noqa: E501
        """MachineDesignConnectorListObject - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._item_connector = None
        self._connected_cables = None
        self._connected_items = None
        self._connected_to_items_string = None
        self._connected_cables_string = None
        self._connector_name = None
        self.discriminator = None

        if item_connector is not None:
            self.item_connector = item_connector
        if connected_cables is not None:
            self.connected_cables = connected_cables
        if connected_items is not None:
            self.connected_items = connected_items
        if connected_to_items_string is not None:
            self.connected_to_items_string = connected_to_items_string
        if connected_cables_string is not None:
            self.connected_cables_string = connected_cables_string
        if connector_name is not None:
            self.connector_name = connector_name

    @property
    def item_connector(self):
        """Gets the item_connector of this MachineDesignConnectorListObject.  # noqa: E501


        :return: The item_connector of this MachineDesignConnectorListObject.  # noqa: E501
        :rtype: ItemConnector
        """
        return self._item_connector

    @item_connector.setter
    def item_connector(self, item_connector):
        """Sets the item_connector of this MachineDesignConnectorListObject.


        :param item_connector: The item_connector of this MachineDesignConnectorListObject.  # noqa: E501
        :type: ItemConnector
        """

        self._item_connector = item_connector

    @property
    def connected_cables(self):
        """Gets the connected_cables of this MachineDesignConnectorListObject.  # noqa: E501


        :return: The connected_cables of this MachineDesignConnectorListObject.  # noqa: E501
        :rtype: list[ItemDomainCableDesign]
        """
        return self._connected_cables

    @connected_cables.setter
    def connected_cables(self, connected_cables):
        """Sets the connected_cables of this MachineDesignConnectorListObject.


        :param connected_cables: The connected_cables of this MachineDesignConnectorListObject.  # noqa: E501
        :type: list[ItemDomainCableDesign]
        """

        self._connected_cables = connected_cables

    @property
    def connected_items(self):
        """Gets the connected_items of this MachineDesignConnectorListObject.  # noqa: E501


        :return: The connected_items of this MachineDesignConnectorListObject.  # noqa: E501
        :rtype: list[Item]
        """
        return self._connected_items

    @connected_items.setter
    def connected_items(self, connected_items):
        """Sets the connected_items of this MachineDesignConnectorListObject.


        :param connected_items: The connected_items of this MachineDesignConnectorListObject.  # noqa: E501
        :type: list[Item]
        """

        self._connected_items = connected_items

    @property
    def connected_to_items_string(self):
        """Gets the connected_to_items_string of this MachineDesignConnectorListObject.  # noqa: E501


        :return: The connected_to_items_string of this MachineDesignConnectorListObject.  # noqa: E501
        :rtype: str
        """
        return self._connected_to_items_string

    @connected_to_items_string.setter
    def connected_to_items_string(self, connected_to_items_string):
        """Sets the connected_to_items_string of this MachineDesignConnectorListObject.


        :param connected_to_items_string: The connected_to_items_string of this MachineDesignConnectorListObject.  # noqa: E501
        :type: str
        """

        self._connected_to_items_string = connected_to_items_string

    @property
    def connected_cables_string(self):
        """Gets the connected_cables_string of this MachineDesignConnectorListObject.  # noqa: E501


        :return: The connected_cables_string of this MachineDesignConnectorListObject.  # noqa: E501
        :rtype: str
        """
        return self._connected_cables_string

    @connected_cables_string.setter
    def connected_cables_string(self, connected_cables_string):
        """Sets the connected_cables_string of this MachineDesignConnectorListObject.


        :param connected_cables_string: The connected_cables_string of this MachineDesignConnectorListObject.  # noqa: E501
        :type: str
        """

        self._connected_cables_string = connected_cables_string

    @property
    def connector_name(self):
        """Gets the connector_name of this MachineDesignConnectorListObject.  # noqa: E501


        :return: The connector_name of this MachineDesignConnectorListObject.  # noqa: E501
        :rtype: str
        """
        return self._connector_name

    @connector_name.setter
    def connector_name(self, connector_name):
        """Sets the connector_name of this MachineDesignConnectorListObject.


        :param connector_name: The connector_name of this MachineDesignConnectorListObject.  # noqa: E501
        :type: str
        """

        self._connector_name = connector_name

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, MachineDesignConnectorListObject):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, MachineDesignConnectorListObject):
            return True

        return self.to_dict() != other.to_dict()
